<p align="center">
Persistent aliases for package managers.
</p>

<p align="center">  
If you like the idea click ⭐ on the repo and <a href="https://twitter.com/intent/tweet?text=Nice%20xontrib%20for%20the%20xonsh%20shell!&url=https://github.com/anki-code/xontrib-jump-to-dir" target="_blank">tweet</a>.
</p>

## Installation

To install use pip:

```bash
xpip install xontrib-pm
# OR: xpip install -U git+https://github.com/anki-code/xontrib-pm
```

## Usage

```xsh
xontrib load pm
aliases['pm']
# ['sudo', 'pacman']
pm-search vim  # sudo pacman -Ss vim
pm-install vim  # sudo pacman -Sy vim
```

## Credits

* [Package manager-independent bash aliases](https://gist.github.com/rroblak/8137276)
* This package was created with [xontrib template](https://github.com/xonsh/xontrib-template).
